# Generated by ariadne-codegen on 2024-03-17 13:24
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel


class ReportEntitlementCheckRequested(BaseModel):
    report_entitlement_check_requested: bool = Field(
        alias="reportEntitlementCheckRequested"
    )


ReportEntitlementCheckRequested.update_forward_refs()



# Generated by ariadne-codegen on 2024-03-17 13:24

from typing import Any, Callable, Dict

SCALARS_PARSE_FUNCTIONS: Dict[Any, Callable[[Any], Any]] = {}
SCALARS_SERIALIZE_FUNCTIONS: Dict[Any, Callable[[Any], Any]] = {}
